@@ -89,6 +89,7 @@ this.readAllData = false;
 this.fileIndex = -1;
 this.fileName = null;
 this.modelIndex = -1;
+this.modelInvRotation = null;
 this.isXLowToHigh = false;
 this.insideOut = false;
 this.dataXYReversed = false;
@@ -143,6 +144,7 @@ this.extendGrid = 0;
 this.isMapped = false;
 this.showTiming = false;
 this.pointSize = 0;
+this.isModelConnected = false;
 Clazz.instantialize (this, arguments);
 }, J.jvxl.readers, "Parameters");
 Clazz.prepareFields (c$, function () {
@@ -194,6 +196,7 @@ this.isAngstroms = false;
 this.isBicolorMap = this.isCutoffAbsolute = this.isPositiveOnly = false;
 this.isCavity = false;
 this.isColorReversed = false;
+this.isModelConnected = false;
 this.isSquared = false;
 this.isSquaredLinear = false;
 this.isContoured = false;
@@ -207,6 +210,7 @@ this.mapLattice = null;
 this.mep_calcType = -1;
 this.minSet = 0;
 this.modelIndex = -1;
+this.modelInvRotation = null;
 this.nContours = 0;
 this.pocket = null;
 this.pointSize = NaN;
@@ -468,6 +472,7 @@ this.moData =  new java.util.Hashtable ();
 }, "~B");
 Clazz.defineMethod (c$, "setMO", 
 function (iMo, linearCombination) {
+this.isModelConnected = true;
 this.qm_moLinearCombination = linearCombination;
 this.qm_moNumber = (linearCombination == null ? Math.abs (iMo) : Clazz.floatToInt (linearCombination[1]));
 this.qmOrbitalType = (this.moData.containsKey ("haveVolumeData") ? 5 : this.moData.containsKey ("gaussians") ? 1 : this.moData.containsKey ("slaters") ? 2 : 0);
