@@ -122,7 +122,8 @@ if (!this.doRender || this.isGhostPass && !(this.doRender = this.g3d.setC (this.
 this.vertices = this.mesh.vs;
 if (this.needTranslucent) this.g3d.setC (JU.C.getColixTranslucent3 (4, true, 0.5));
 return true;
-}this.vertices = (this.mesh.scale3d == 0 && this.mesh.mat4 == null ? this.mesh.vs : this.mesh.getOffsetVertices (this.thePlane));
+}if (this.mesh.isModelConnected) this.mesh.mat4 = this.ms.am[this.mesh.modelIndex].mat4;
+this.vertices = (this.mesh.scale3d == 0 && this.mesh.mat4 == null ? this.mesh.vs : this.mesh.getOffsetVertices (this.thePlane));
 if (this.mesh.lineData == null) {
 if ((this.vertexCount = this.mesh.vc) == 0) return false;
 this.normixes = this.mesh.normixes;
