@@ -246,7 +246,12 @@ m.setTokenProperty (tokProp, bProp);
 }, "J.shape.Mesh,~N,~B,~B");
 Clazz.defineMethod (c$, "getPropDataMC", 
 function (property, data) {
-if (property === "getNames") {
+if (property === "keys") {
+var keys = (Clazz.instanceOf (data[1], JU.Lst) ? data[1] :  new JU.Lst ());
+data[1] = keys;
+keys.addLast ("count");
+keys.addLast ("getCenter");
+}if (property === "getNames") {
 var map = data[0];
 var withDollar = (data[1]).booleanValue ();
 for (var i = this.meshCount; --i >= 0; ) if (this.meshes[i] != null && this.meshes[i].vc != 0) map.put ((withDollar ? "$" : "") + this.meshes[i].thisID, JS.T.tokenOr);
@@ -264,6 +269,10 @@ var list = this.getMeshList (key, true);
 if (list.size () == 0) return false;
 data[1] = list.get (0).thisID;
 return true;
+}if (property === "index") {
+var m = this.getMesh (data[0]);
+data[1] = Integer.$valueOf (m == null ? -1 : m.index);
+return true;
 }if (property === "getCenter") {
 var id = data[0];
 var index = (data[1]).intValue ();
@@ -272,7 +281,7 @@ if ((m = this.getMesh (id)) == null || m.vs == null) return false;
 if (index == 2147483647) data[2] = JU.P3.new3 (m.index + 1, this.meshCount, m.vc);
  else data[2] = m.vs[m.getVertexIndexFromNumber (index)];
 return true;
-}return false;
+}return this.getPropShape (property, data);
 }, "~S,~A");
 Clazz.defineMethod (c$, "getMeshList", 
 function (key, justOne) {
@@ -287,20 +296,27 @@ if (justOne) break;
 return list;
 }, "~S,~B");
 Clazz.defineMethod (c$, "getPropMC", 
-function (property) {
-var m;
+function (property, index) {
+var m = this.currentMesh;
+if (index >= 0 && (index >= this.meshCount || (m = this.meshes[index]) == null)) return null;
 if (property === "count") {
 var n = 0;
 for (var i = 0; i < this.meshCount; i++) if ((m = this.meshes[i]) != null && m.vc > 0) n++;
 
 return Integer.$valueOf (n);
-}if (property === "ID") return (this.currentMesh == null ? null : this.currentMesh.thisID);
+}if (property === "bsVertices") {
+if (m == null) return null;
+var lst =  new JU.Lst ();
+lst.addLast (m.vs);
+lst.addLast (m.getVisibleVBS ());
+return lst;
+}if (property === "ID") return (m == null ? null : m.thisID);
 if (property.startsWith ("list")) {
 this.clean ();
 var sb =  new JU.SB ();
 var k = 0;
 var isNamed = property.length > 5;
-var id = (property.equals ("list") ? null : isNamed ? property.substring (5) : this.currentMesh == null ? null : this.currentMesh.thisID);
+var id = (property.equals ("list") ? null : isNamed ? property.substring (5) : m == null ? null : m.thisID);
 for (var i = 0; i < this.meshCount; i++) {
 m = this.meshes[i];
 if (id != null && !id.equalsIgnoreCase (m.thisID)) continue;
@@ -319,11 +335,11 @@ var info = this.getProperty ("jvxlFileInfo", 0);
 if (info != null) sb.append (info).appendC ('\n');
 }}
 return sb.toString ();
-}if (property === "vertices") return this.getVertices (this.currentMesh);
-if (property === "getInfo") return (this.currentMesh == null ? null : this.currentMesh.getInfo (false));
-if (property === "getData") return (this.currentMesh == null ? null : this.currentMesh.getInfo (true));
+}if (property === "vertices") return this.getVertices (m);
+if (property === "info") return (m == null ? null : m.getInfo (false));
+if (property === "data") return (m == null ? null : m.getInfo (true));
 return null;
-}, "~S");
+}, "~S,~N");
 Clazz.defineMethod (c$, "getVertices", 
  function (mesh) {
 if (mesh == null) return null;
