@@ -256,7 +256,7 @@ var iter = this.vwr.getSelectedAtomIterator (bsB, isSelf, false, isMultiModel);
 for (var ia = bsA.nextSetBit (0); ia >= 0; ia = bsA.nextSetBit (ia + 1)) {
 var atomA = this.atoms[ia];
 var vdwA = atomA.getVanderwaalsRadiusFloat (this.vwr, J.c.VDW.AUTO);
-if (isMultiModel) this.vwr.setIteratorForPoint (iter, -1, ad.atomXyz[ia], ad.atomRadius[ia] + maxRadius);
+if (isMultiModel) this.vwr.setIteratorForPoint (iter, -1, ad.atoms[ia], ad.atomRadius[ia] + maxRadius);
  else this.vwr.setIteratorForAtom (iter, ia, ad.atomRadius[ia] + maxRadius);
 while (iter.hasNext ()) {
 var ib = iter.next ();
