@@ -198,11 +198,11 @@ Clazz.defineMethod (c$, "getId",
 return "mo_model" + this.vwr.getModelNumberDotted (modelIndex);
 }, "~N");
 Clazz.overrideMethod (c$, "getProperty", 
-function (propertyName, param) {
+function (propertyName, index) {
 if (propertyName.startsWith ("list")) {
 var s = "";
 if (propertyName.equals ("list")) {
-s = this.getPropI ("list");
+s = this.getPropI ("list", index);
 if (s.length > 1) s += "cutoff = " + this.jvxlData.cutoff + "\n";
 s = "\n" + s;
 }return this.getMoInfo (-1) + s;
@@ -212,12 +212,11 @@ if (propertyName === "showMO") {
 var str =  new JU.SB ();
 var mos = (this.sg.params.moData.get ("mos"));
 var nOrb = (mos == null ? 0 : mos.size ());
-var thisMO = param;
+var thisMO = index;
 var currentMO = this.$moNumber;
 var isShowCurrent = (thisMO == -2147483648);
-if (thisMO == 2147483647) {
-thisMO = currentMO;
-}if (nOrb == 0 || isShowCurrent && currentMO == 0) return "";
+if (isShowCurrent) thisMO = currentMO;
+if (nOrb == 0 || isShowCurrent && currentMO == 0) return "";
 var doOneMo = (thisMO != 0);
 if (currentMO == 0) thisMO = 0;
 var haveHeader = false;
@@ -229,15 +228,15 @@ this.setPropI ("init", this.sg.params, null);
 this.setOrbital (i, null);
 }this.jvxlData.moleculeXml = this.vwr.getModelCml (this.vwr.getModelUndeletedAtomsBitSet (this.thisMesh.modelIndex), 100, true, false);
 if (!haveHeader) {
-str.append (J.jvxl.data.JvxlCoder.jvxlGetFile (this.jvxlData, null, null, "HEADERONLY", true, nTotal, null, null));
+str.append (J.jvxl.data.JvxlCoder.jvxlGetFileVwr (this.vwr, this.jvxlData, null, null, "HEADERONLY", true, nTotal, null, null));
 haveHeader = true;
-}str.append (J.jvxl.data.JvxlCoder.jvxlGetFile (this.jvxlData, null, this.jvxlData.title, null, false, 1, this.thisMesh.getState (this.myType), (this.thisMesh.scriptCommand == null ? "" : this.thisMesh.scriptCommand)));
+}str.append (J.jvxl.data.JvxlCoder.jvxlGetFileVwr (this.vwr, this.jvxlData, null, this.jvxlData.title, null, false, 1, this.thisMesh.getState (this.myType), (this.thisMesh.scriptCommand == null ? "" : this.thisMesh.scriptCommand)));
 if (!doOneMo) this.setPropI ("delete", "mo_show", null);
 if (nTotal == 1) break;
 }
-str.append (J.jvxl.data.JvxlCoder.jvxlGetFile (this.jvxlData, null, null, "TRAILERONLY", true, 0, null, null));
+str.append (J.jvxl.data.JvxlCoder.jvxlGetFileVwr (this.vwr, this.jvxlData, null, null, "TRAILERONLY", true, 0, null, null));
 return str.toString ();
-}return this.getPropI (propertyName);
+}return this.getPropI (propertyName, index);
 }, "~S,~N");
 Clazz.defineMethod (c$, "getMoInfo", 
 function (modelIndex) {
@@ -324,6 +323,7 @@ this.setPropI ("monteCarloCount", this.moMonteCarloCount, null);
 this.setPropI ("squareLinear", this.moSquareLinear, null);
 this.setPropI ("title", this.moTitleFormat, null);
 this.setPropI ("fileName", this.vwr.fm.getFileName (), null);
+this.currentMesh.modelIndex = this.modelIndex;
 this.setPropI ("molecularOrbital", linearCombination == null ? Integer.$valueOf (moNumber) : linearCombination, null);
 if (this.moPlane != null && this.moColorNeg != null) this.setPropI ("colorRGB", this.moColorNeg, null);
 if (this.moPlane != null && this.moColorPos != null) this.setPropI ("colorRGB", this.moColorPos, null);
