@@ -269,7 +269,7 @@ return (this.valence < 0);
 });
 Clazz.defineMethod (c$, "setValence", 
 function (nBonds) {
-if (!this.isDeleted ()) this.valence = (nBonds < 0 ? 0 : nBonds < 0xEF ? nBonds : 0xEF);
+if (!this.isDeleted ()) this.valence = (nBonds < 0 ? 0 : nBonds <= 0x7F ? nBonds : 0x7F);
 }, "~N");
 Clazz.overrideMethod (c$, "getValence", 
 function () {
