@@ -47,6 +47,7 @@ this.aaRet = null;
 if (!Clazz.isClassDefined ("JM.AtomCollection.AtomSorter")) {
 JM.AtomCollection.$AtomCollection$AtomSorter$ ();
 }
+this.atomCapacity = 0;
 Clazz.instantialize (this, arguments);
 }, JM, "AtomCollection");
 Clazz.defineMethod (c$, "setupAC", 
@@ -847,7 +848,7 @@ return contender.sZ > 1 && !this.g3d.isClippedZ (contender.sZ) && this.g3d.isInD
 }, "JM.Atom,~N,~N,~N,JM.Atom");
 Clazz.defineMethod (c$, "fillADa", 
 function (atomData, mode) {
-atomData.atomXyz = this.at;
+atomData.xyz = atomData.atoms = this.at;
 atomData.ac = this.ac;
 atomData.atomicNumber =  Clazz.newIntArray (this.ac, 0);
 var includeRadii = ((mode & 2) != 0);
@@ -1840,6 +1841,10 @@ if (list.size () == 0) toDelete.addLast (key);
 for (var i = toDelete.size (); --i >= 0; ) this.atomTensors.remove (toDelete.get (i));
 
 }, "JU.BS");
+Clazz.defineMethod (c$, "setCapacity", 
+function (nAtoms) {
+this.atomCapacity += nAtoms;
+}, "~N");
 Clazz.defineMethod (c$, "setAtomTensors", 
 function (atomIndex, list) {
 if (list == null || list.size () == 0) return;
@@ -1856,6 +1861,15 @@ this.addTensor (t, t.type);
 if (t.altType != null) this.addTensor (t, t.altType);
 }
 }, "~N,JU.Lst");
+Clazz.defineMethod (c$, "addTensor", 
+function (t, type) {
+type = type.toLowerCase ();
+var tensors = this.atomTensors.get (type);
+if (tensors == null) {
+this.atomTensors.put (type, tensors =  new JU.Lst ());
+tensors.ensureCapacity (this.atomCapacity);
+}tensors.addLast (t);
+}, "JU.Tensor,~S");
 c$.getTensorList = Clazz.defineMethod (c$, "getTensorList", 
  function (list) {
 var pt = -1;
@@ -1893,13 +1907,6 @@ if (t != null && (type.equals (t.type) || type.equals (t.altType))) return t;
 }
 }return null;
 }, "~N,~S");
-Clazz.defineMethod (c$, "addTensor", 
-function (t, type) {
-type = type.toLowerCase ();
-var tensors = this.atomTensors.get (type);
-if (tensors == null) this.atomTensors.put (type, tensors =  new JU.Lst ());
-tensors.addLast (t);
-}, "JU.Tensor,~S");
 Clazz.defineMethod (c$, "getAllAtomTensors", 
 function (type) {
 if (this.atomTensors == null) return null;
