@@ -813,8 +813,8 @@ this.setNBOType (moData, nboType);
 if (lc == null && moNumber == 2147483647) return;
 }var mos = null;
 var mo;
-var f;
 var nOrb = 0;
+var f = null;
 if (lc == null || lc.length < 2) {
 if (lc != null && lc.length == 1) offset = 0;
 var lastMoNumber = (moData.containsKey ("lastMoNumber") ? (moData.get ("lastMoNumber")).intValue () : 0);
@@ -829,7 +829,7 @@ if (offset != 2147483647) {
 if (moData.containsKey ("HOMO")) {
 moNumber = (moData.get ("HOMO")).intValue () + offset;
 } else {
-moNumber = -1;
+moNumber = nOrb;
 for (var i = 0; i < nOrb; i++) {
 mo = mos.get (i);
 if ((f = mo.get ("occupancy")) != null) {
@@ -844,9 +844,9 @@ break;
 }continue;
 }break;
 }
-if (moNumber < 0) this.error (28);
+if (f == null) this.error (28);
 moNumber += offset;
-}JU.Logger.info ("MO " + moNumber);
+}if (!this.chk) JU.Logger.info ("MO " + moNumber);
 }if (moNumber < 1 || moNumber > nOrb) eval.errorStr (26, "" + nOrb);
 }moNumber = Math.abs (moNumber);
 moData.put ("lastMoNumber", Integer.$valueOf (moNumber));
@@ -892,6 +892,7 @@ var isIsosurface = (iShape == 24);
 var isPmesh = (iShape == 29);
 var isPlot3d = (iShape == 30);
 var isLcaoCartoon = (iShape == 26);
+var isSilent = (isLcaoCartoon || this.tokAt (1) == 12291);
 var surfaceObjectSeen = false;
 var planeSeen = false;
 var isMapped = false;
@@ -952,6 +953,10 @@ var propertyValue = null;
 this.getToken (i);
 if (eval.theTok == 1073741824) str = this.paramAsStr (i);
 switch (eval.theTok) {
+case 1073742148:
+isSilent = true;
+sbCommand.append (" silent");
+continue;
 case 603979870:
 smoothing = (this.getToken (++i).tok == 1073742335 ? Boolean.TRUE : eval.theTok == 1073742334 ? Boolean.FALSE : null);
 if (smoothing == null) this.invArg ();
@@ -2107,7 +2112,7 @@ this.setShapeProperty (iShape, "finalize", sbCommand.toString ());
 cmd = sbCommand.toString ();
 this.setShapeProperty (iShape, "finalize", (cmd.indexOf ("; isosurface map") == 0 ? "" : " select " + JU.Escape.eBS (bsSelect) + " ") + cmd);
 s = this.getShapeProperty (iShape, "ID");
-if (s != null && !eval.tQuiet) {
+if (s != null && !eval.tQuiet && !isSilent) {
 cutoff = (this.getShapeProperty (iShape, "cutoff")).floatValue ();
 if (Float.isNaN (cutoff) && !Float.isNaN (sigma)) JU.Logger.error ("sigma not supported");
 s += " created " + this.getShapeProperty (iShape, "message");
@@ -2122,11 +2127,11 @@ if (doCalcVolume) this.showString (svol);
 } else {
 if (doCalcArea) s += "\n" + sarea;
 if (doCalcVolume) s += "\n" + svol;
-}}if (s != null) this.showString (s);
+}}if (s != null && !isSilent) this.showString (s);
 }if (translucency != null) this.setShapeProperty (iShape, "translucency", translucency);
 this.setShapeProperty (iShape, "clear", null);
 if (toCache) this.setShapeProperty (iShape, "cache", null);
-if (iShape != 26 && !isDisplay && !haveSlab) this.listIsosurface (iShape);
+if (!isSilent && !isDisplay && !haveSlab && eval.theTok != 12291) this.listIsosurface (iShape);
 }, "~N");
 Clazz.defineMethod (c$, "lcaoCartoon", 
  function () {
@@ -2735,7 +2740,7 @@ var e = ( new JS.ScriptEval ()).setViewer (this.vwr);
 try {
 e.compileScript (null, "function " + fname + "(" + xyz + ") { return " + ret + "}", false);
 var params =  new JU.Lst ();
-for (var i = 0; i < xyz.length; i += 2) params.addLast (JS.SV.newV (3, Float.$valueOf (0)).setName (xyz.substring (i, i + 1)));
+for (var i = 0; i < xyz.length; i += 2) params.addLast (JS.SV.newF (0).setName (xyz.substring (i, i + 1)));
 
 return  Clazz.newArray (-1, [e.aatoken[0][1].value, params]);
 } catch (ex) {
