@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (null, "JS.MathExt", ["java.lang.Float", "$.Number", "java.util.Date", "$.Hashtable", "$.Random", "JU.AU", "$.BS", "$.CU", "$.Lst", "$.M4", "$.Measure", "$.P3", "$.P4", "$.PT", "$.Quat", "$.SB", "$.V3", "J.api.Interface", "J.atomdata.RadiusData", "J.bspt.Bspt", "J.c.VDW", "J.i18n.GT", "JM.BondSet", "JS.SV", "$.ScriptParam", "$.T", "JU.BSUtil", "$.Escape", "$.JmolMolecule", "$.Logger", "$.Parser", "$.Point3fi", "$.SimpleUnitCell"], function () {
+Clazz.load (null, "JS.MathExt", ["java.lang.Float", "$.Number", "java.util.Date", "$.Hashtable", "$.Random", "JU.AU", "$.BS", "$.CU", "$.Lst", "$.M4", "$.Measure", "$.P3", "$.P4", "$.PT", "$.Quat", "$.SB", "$.V3", "J.api.Interface", "J.atomdata.RadiusData", "J.bspt.Bspt", "J.c.VDW", "J.i18n.GT", "JM.BondSet", "JS.SV", "$.ScriptParam", "$.T", "JU.BSUtil", "$.Escape", "$.JmolMolecule", "$.Logger", "$.Parser", "$.Point3fi", "$.SimpleUnitCell", "JV.FileManager", "$.JC"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.vwr = null;
 this.e = null;
@@ -101,6 +101,8 @@ case 1275068932:
 return this.evaluateString (mp, op.intValue, args);
 case 134217751:
 return this.evaluatePoint (mp, args);
+case 1073742102:
+return this.evaluatePointGroup (mp, args);
 case 134256131:
 return this.evaluatePrompt (mp, args);
 case 134219268:
@@ -129,6 +131,55 @@ return this.evaluateWrite (mp, args);
 }
 return false;
 }, "JS.ScriptMathProcessor,JS.T,~A,~N");
+Clazz.defineMethod (c$, "evaluatePointGroup", 
+ function (mp, args) {
+var pts;
+var center = null;
+var distanceTolerance = NaN;
+var linearTolerance = NaN;
+var bsAtoms;
+switch (args.length) {
+case 4:
+linearTolerance = args[3].asFloat ();
+case 3:
+distanceTolerance = args[2].asFloat ();
+case 2:
+switch (args[1].tok) {
+case 8:
+center = JS.SV.ptValue (args[1]);
+break;
+case 10:
+bsAtoms = JS.SV.getBitSet (args[0], false);
+var iatom = bsAtoms.nextSetBit (0);
+if (iatom < 0 || iatom >= this.vwr.ms.ac || bsAtoms.cardinality () != 1) return false;
+center = this.vwr.ms.at[iatom];
+break;
+}
+case 1:
+switch (args[0].tok) {
+case 7:
+var points = args[0].getList ();
+pts =  new Array (points.size ());
+for (var i = pts.length; --i >= 0; ) pts[i] = JS.SV.ptValue (points.get (i));
+
+break;
+case 10:
+bsAtoms = JS.SV.getBitSet (args[0], false);
+var atoms = this.vwr.ms.getAtomPointVector (bsAtoms);
+pts =  new Array (atoms.size ());
+for (var i = pts.length; --i >= 0; ) pts[i] = atoms.get (i);
+
+break;
+default:
+return false;
+}
+break;
+default:
+return false;
+}
+var pointGroup = this.vwr.ms.getSymTemp (true).setPointGroup (null, center, pts, null, false, Float.isNaN (distanceTolerance) ? this.vwr.getFloat (570425382) : distanceTolerance, Float.isNaN (linearTolerance) ? this.vwr.getFloat (570425384) : linearTolerance, true);
+return mp.addXMap (pointGroup.getPointGroupInfo (-1, false, true, null, 0, 1));
+}, "JS.ScriptMathProcessor,~A");
 Clazz.defineMethod (c$, "evaluateUnitCell", 
  function (mp, args) {
 var lastParam = args.length - 1;
@@ -267,8 +318,8 @@ if (map == null) continue;
 map.put ("_bin", JS.SV.newI (bin));
 var v1 = f0 + df * bin;
 var v2 = v1 + df;
-map.put ("_binMin", JS.SV.newV (3, Float.$valueOf (bin == 0 ? -3.4028235E38 : v1)));
-map.put ("_binMax", JS.SV.newV (3, Float.$valueOf (bin == nbins - 1 ? 3.4028235E38 : v2)));
+map.put ("_binMin", JS.SV.newF (bin == 0 ? -3.4028235E38 : v1));
+map.put ("_binMax", JS.SV.newF (bin == nbins - 1 ? 3.4028235E38 : v2));
 }}
 return mp.addXAI (array);
 }, "JS.ScriptMathProcessor,~A");
@@ -451,8 +502,7 @@ throw ex;
 }, "JS.ScriptMathProcessor,~A");
 Clazz.defineMethod (c$, "evaluateConnected", 
  function (mp, args, tok) {
-var isBondCount = (tok == 1228931587);
-if (args.length > 5 || isBondCount && args.length != 1) return false;
+if (args.length > 5) return false;
 var min = -2147483648;
 var max = 2147483647;
 var fmin = 0;
@@ -823,16 +873,15 @@ throw ex;
 var isReverse = (flags.indexOf ("v") >= 0);
 var isCaseInsensitive = (flags.indexOf ("i") >= 0);
 var asMatch = (flags.indexOf ("m") >= 0);
-var isPattern = (args.length == 2);
+var checkEmpty = (sFind.length == 0);
+var isPattern = (!checkEmpty && args.length == 2);
 if (isList || isPattern) {
-var pm = this.getPatternMatcher ();
+var pm = (isPattern ? this.getPatternMatcher () : null);
 var pattern = null;
-var list = null;
 var svlist = (isList ? x1.getList () : null);
-if (sFind.length > 0) {
+if (isPattern) {
 try {
-pattern = (sFind.length == 0 ? null : pm.compile (sFind, isCaseInsensitive));
-list = JS.SV.strListValue (x1);
+pattern = pm.compile (sFind, isCaseInsensitive);
 } catch (ex) {
 if (Clazz.exceptionOf (ex, Exception)) {
 this.e.evalError (ex.toString (), null);
@@ -840,7 +889,8 @@ this.e.evalError (ex.toString (), null);
 throw ex;
 }
 }
-}var nlist = (list == null ? svlist.size () : list.length);
+}var list = (checkEmpty ? null : JS.SV.strListValue (x1));
+var nlist = (checkEmpty ? svlist.size () : list.length);
 if (JU.Logger.debugging) JU.Logger.debug ("finding " + sFind);
 var bs =  new JU.BS ();
 var n = 0;
@@ -849,7 +899,7 @@ var v = (asMatch ?  new JU.Lst () : null);
 var what = "";
 for (var i = 0; i < nlist; i++) {
 var isMatch;
-if (pattern == null) {
+if (checkEmpty) {
 var o = svlist.get (i);
 switch (o.tok) {
 case 6:
@@ -864,10 +914,12 @@ break;
 default:
 isMatch = true;
 }
-} else {
+} else if (isPattern) {
 what = list[i];
 matcher = pattern.matcher (what);
 isMatch = matcher.find ();
+} else {
+isMatch = (JS.SV.sValue (svlist.get (i)).indexOf (sFind) >= 0);
 }if (asMatch && isMatch || !asMatch && isMatch == !isReverse) {
 n++;
 bs.set (i);
@@ -898,7 +950,9 @@ var pt = 0;
 var tok = (args.length == 0 ? 0 : args[0].tok);
 if (args.length == 2 && (tok == 7 || tok == 6 || tok == 14)) {
 return mp.addXObj (this.vwr.extractProperty (args[0].value, args[1].value.toString (), -1));
-}var propertyName = (args.length > 0 ? JS.SV.sValue (args[pt++]) : "");
+}var bsSelect = (isAtomProperty && args.length == 1 && args[0].tok == 10 ? args[0].value : null);
+var pname = (bsSelect == null && args.length > 0 ? JS.SV.sValue (args[pt++]) : "");
+var propertyName = pname;
 var lc = propertyName.toLowerCase ();
 if (!isSelect && lc.indexOf ("[select ") < 0) propertyName = lc;
 var isJSON = false;
@@ -908,10 +962,41 @@ propertyName = JS.SV.sValue (args[pt++]);
 }var x = null;
 if (isAtomProperty) {
 x = mp.getX ();
-if (x.tok != 10) {
+switch (x.tok) {
+case 10:
+break;
+case 4:
+var name = x.value;
+var data =  new Array (3);
+var shapeID;
+if (name.startsWith ("$")) {
+name = name.substring (1);
+shapeID = this.vwr.shm.getShapeIdFromObjectName (name);
+if (shapeID >= 0) {
+data[0] = name;
+this.vwr.shm.getShapePropertyData (shapeID, "index", data);
+if (data[1] != null && !pname.equals ("index")) {
+var index = (data[1]).intValue ();
+data[1] = this.vwr.shm.getShapePropertyIndex (shapeID, pname.intern (), index);
+}}} else {
+shapeID = JV.JC.shapeTokenIndex (JS.T.getTokFromName (name));
+if (shapeID >= 0) {
+data[0] = pname;
+data[1] = Integer.$valueOf (-1);
+this.vwr.shm.getShapePropertyData (shapeID, pname.intern (), data);
+}}return (data[1] == null ? mp.addXStr ("") : mp.addXObj (data[1]));
+case 7:
+if (bsSelect != null) {
+var l0 = x.getList ();
+var lst =  new JU.Lst ();
+for (var i = bsSelect.nextSetBit (0); i >= 0; i = bsSelect.nextSetBit (i + 1)) lst.addLast (l0.get (i));
+
+return mp.addXList (lst);
+}default:
 if (isSelect) propertyName = "[SELECT " + propertyName + "]";
 return mp.addXObj (this.vwr.extractProperty (x, propertyName, -1));
-}}if (isAtomProperty && !lc.startsWith ("bondinfo") && !lc.startsWith ("atominfo")) propertyName = "atomInfo." + propertyName;
+}
+}if (isAtomProperty && !lc.startsWith ("bondinfo") && !lc.startsWith ("atominfo")) propertyName = "atomInfo." + propertyName;
 var propertyValue = "";
 if (propertyName.equalsIgnoreCase ("fileContents") && args.length > 2) {
 var s = JS.SV.sValue (args[1]);
@@ -1161,11 +1246,11 @@ for (var i = 0; i < len; i++) {
 if (isScalar2) b = scalar;
  else if (x2.tok == 7) b = alist2.get (i);
  else if (Float.isNaN (list2[i])) b = JS.SV.getVariable (JS.SV.unescapePointOrBitsetAsVariable (sList2[i]));
- else b = JS.SV.newV (3, Float.$valueOf (list2[i]));
+ else b = JS.SV.newF (list2[i]);
 if (!isScalar1) {
 if (isArray1) a = alist1.get (i);
  else if (Float.isNaN (list1[i])) a = JS.SV.getVariable (JS.SV.unescapePointOrBitsetAsVariable (sList1[i]));
- else a = JS.SV.newV (3, Float.$valueOf (list1[i]));
+ else a = JS.SV.newF (list1[i]);
 }if (tok == 1275069446) {
 if (a.tok != 7) {
 var l =  new JU.Lst ();
@@ -1199,8 +1284,7 @@ case 2:
 nBytesMax = (args[1].tok == 2 ? args[1].asInt () : -1);
 asBytes = args[1].tok == 1073742335;
 case 1:
-file = JS.SV.sValue (args[0]);
-file = file.$replace ('\\', '/');
+file = JV.FileManager.fixDOSName (JS.SV.sValue (args[0]));
 break;
 default:
 return false;
@@ -1755,8 +1839,7 @@ case 134222350:
 this.e.runScriptBuffer ("show " + s, sb, true);
 break;
 case 134238732:
-sb.append (this.vwr.jsEval (s));
-break;
+return mp.addX (this.vwr.jsEvalSV (s));
 }
 s = sb.toString ();
 var f;
@@ -2103,19 +2186,59 @@ var asMap = isWithinModelSet;
 return mp.addXObj (this.vwr.ms.getUnitCellPointsWithin (distance, bs, pt, asMap));
 }if (pt != null) {
 if (args[last].tok == 7) {
-var sv = args[2].getList ();
+var sv = args[last].getList ();
 var pts =  new JU.Lst ();
 var bspt =  new J.bspt.Bspt (3, 0);
-for (var i = sv.size (); --i >= 0; ) {
-bspt.addTuple (JS.SV.ptValue (sv.get (i)));
+var iter;
+if (Float.isNaN (pt.x)) {
+var p;
+var pt3 =  new Array (sv.size ());
+for (var i = pt3.length; --i >= 0; ) {
+var p3 = JS.SV.ptValue (sv.get (i));
+if (p3 == null) return false;
+p =  new JU.Point3fi ();
+p.setT (p3);
+p.i = i;
+pt3[i] = p;
+bspt.addTuple (p);
 }
-var iter = bspt.allocateCubeIterator ();
-iter.initialize (pt, distance, false);
+iter = bspt.allocateCubeIterator ();
+var bsp = JU.BSUtil.newBitSet2 (0, sv.size ());
+for (var i = pt3.length; --i >= 0; ) {
+iter.initialize (p = pt3[i], distance, false);
 var d2 = distance * distance;
+var n = 0;
+while (iter.hasMoreElements ()) {
+var pt2 = iter.nextElement ();
+if (bsp.get (pt2.i) && pt2.distanceSquared (p) <= d2 && (++n > 1)) bsp.clear (pt2.i);
+}
+}
+for (var i = bsp.nextSetBit (0); i >= 0; i = bsp.nextSetBit (i + 1)) pts.addLast (JU.P3.newP (pt3[i]));
+
+return mp.addXList (pts);
+}var d2;
+if (distance == 0) {
+var pt3 = null;
+var pta;
+d2 = 3.4028235E38;
+for (var i = sv.size (); --i >= 0; ) {
+pta = JS.SV.ptValue (sv.get (i));
+distance = pta.distanceSquared (pt);
+if (distance < d2) {
+pt3 = pta;
+d2 = distance;
+}}
+return (pt3 == null ? mp.addXStr ("") : mp.addXPt (pt3));
+}for (var i = sv.size (); --i >= 0; ) bspt.addTuple (JS.SV.ptValue (sv.get (i)));
+
+iter = bspt.allocateCubeIterator ();
+iter.initialize (pt, distance, false);
+d2 = distance * distance;
 while (iter.hasMoreElements ()) {
 var pt2 = iter.nextElement ();
 if (pt2.distanceSquared (pt) <= d2) pts.addLast (pt2);
 }
+iter.release ();
 return mp.addXList (pts);
 }return mp.addXBs (this.vwr.getAtomsNearPt (distance, pt));
 }if (tok == 1086324744) return mp.addXBs (this.vwr.ms.getSequenceBits (withinStr, bs,  new JU.BS ()));
