@@ -178,7 +178,7 @@ return this.wasX = true;
 Clazz.defineMethod (c$, "addXFloat", 
 function (x) {
 if (Float.isNaN (x)) return this.addXStr ("NaN");
-this.putX (JS.SV.newV (3, Float.$valueOf (x)));
+this.putX (JS.SV.newF (x));
 return this.wasX = true;
 }, "~N");
 Clazz.defineMethod (c$, "addXBs", 
@@ -208,7 +208,7 @@ if (this.wasX) {
 var f = (x.value).floatValue ();
 if (f < 0 || f == 0 && 1 / f == -Infinity) {
 this.addOp (JS.T.tokenMinus);
-v = JS.SV.newV (3, Float.$valueOf (-f));
+v = JS.SV.newF (-f);
 break;
 }}v = JS.SV.newV (3, x.value);
 break;
