@@ -134,6 +134,8 @@ if (bs.isEmpty ()) ms.haveHiddenBonds = false;
  else commands.append ("  hide ").append (JU.Escape.eBond (bs)).append (";\n");
 }this.vwr.setModelVisibility ();
 if (withProteinStructure) commands.append (ms.getProteinStructureState (null, isAll ? 1073742327 : 1073742158));
+for (var i = 0; i < modelCount; i++) if (models[i].mat4 != null) commands.append ("  frame orientation " + ms.getModelNumberDotted (i) + JU.Escape.matrixToScript (models[i].mat4) + ";\n");
+
 this.getShapeState (commands, isAll, 2147483647);
 if (isAll) {
 var needOrientations = false;
@@ -141,28 +143,32 @@ for (var i = 0; i < modelCount; i++) if (models[i].isJmolDataFrame) {
 needOrientations = true;
 break;
 }
+var sb =  new JU.SB ();
 for (var i = 0; i < modelCount; i++) {
-var fcmd = "  frame " + ms.getModelNumberDotted (i);
+var m = models[i];
+sb.setLength (0);
 var s = ms.getInfo (i, "modelID");
-if (s != null && !s.equals (ms.getInfo (i, "modelID0"))) commands.append (fcmd).append ("; frame ID ").append (JU.PT.esc (s)).append (";\n");
+if (s != null && !s.equals (ms.getInfo (i, "modelID0"))) sb.append ("  frame ID ").append (JU.PT.esc (s)).append (";\n");
 var t = ms.frameTitles[i];
-if (t != null && t.length > 0) commands.append (fcmd).append ("; frame title ").append (JU.PT.esc (t)).append (";\n");
-if (needOrientations && models[i].orientation != null && !ms.isTrajectorySubFrame (i)) commands.append (fcmd).append ("; ").append (models[i].orientation.getMoveToText (false)).append (";\n");
-if (models[i].frameDelay != 0 && !ms.isTrajectorySubFrame (i)) commands.append (fcmd).append ("; frame delay ").appendF (models[i].frameDelay / 1000).append (";\n");
-if (models[i].simpleCage != null) {
-commands.append (fcmd).append ("; unitcell ").append (JU.Escape.eAP (models[i].simpleCage.getUnitCellVectors ())).append (";\n");
-this.getShapeState (commands, isAll, 33);
-}}
+if (t != null && t.length > 0) sb.append ("  frame title ").append (JU.PT.esc (t)).append (";\n");
+if (needOrientations && m.orientation != null && !ms.isTrajectorySubFrame (i)) sb.append ("  ").append (m.orientation.getMoveToText (false)).append (";\n");
+if (m.frameDelay != 0 && !ms.isTrajectorySubFrame (i)) sb.append ("  frame delay ").appendF (m.frameDelay / 1000).append (";\n");
+if (m.simpleCage != null) {
+sb.append ("  unitcell ").append (JU.Escape.eAP (m.simpleCage.getUnitCellVectors ())).append (";\n");
+this.getShapeState (sb, isAll, 33);
+}if (sb.length () > 0) commands.append ("  frame " + ms.getModelNumberDotted (i) + ";\n").appendSB (sb);
+}
 var loadUC = false;
 if (ms.unitCells != null) {
 var haveModulation = false;
 for (var i = 0; i < modelCount; i++) {
 var symmetry = ms.getUnitCell (i);
 if (symmetry == null) continue;
-commands.append ("  frame ").append (ms.getModelNumberDotted (i));
-if (symmetry.getState (commands)) loadUC = true;
-commands.append (";\n");
-haveModulation = new Boolean (haveModulation | (this.vwr.ms.getLastVibrationVector (i, 1275072532) >= 0)).valueOf ();
+sb.setLength (0);
+if (symmetry.getState (sb)) {
+loadUC = true;
+commands.append ("  frame ").append (ms.getModelNumberDotted (i)).appendSB (sb).append (";\n");
+}haveModulation = new Boolean (haveModulation | (this.vwr.ms.getLastVibrationVector (i, 1275072532) >= 0)).valueOf ();
 }
 if (loadUC) this.vwr.shm.loadShape (33);
 this.getShapeState (commands, isAll, 33);
@@ -562,20 +568,6 @@ if (!isUnitCell && tickInfo.scale != null) sb.append (" scale ").append (JU.Esca
 if (addFirst && !Float.isNaN (tickInfo.first) && tickInfo.first != 0) sb.append (" first ").appendF (tickInfo.first);
 if (tickInfo.reference != null) sb.append (" point ").append (JU.Escape.eP (tickInfo.reference));
 }, "JU.SB,JM.TickInfo,~B");
-Clazz.overrideMethod (c$, "getShapeSetState", 
-function (as, shape, monomerCount, monomers, bsSizeDefault, temp, temp2) {
-var type = JV.JC.shapeClassBases[shape.shapeID];
-for (var i = 0; i < monomerCount; i++) {
-var atomIndex1 = monomers[i].firstAtomIndex;
-var atomIndex2 = monomers[i].lastAtomIndex;
-if (as.bsSizeSet != null && (as.bsSizeSet.get (i) || as.bsColixSet != null && as.bsColixSet.get (i))) {
-if (bsSizeDefault.get (i)) {
-JU.BSUtil.setMapBitSet (temp, atomIndex1, atomIndex2, type + (as.bsSizeSet.get (i) ? " on" : " off"));
-} else {
-JU.BSUtil.setMapBitSet (temp, atomIndex1, atomIndex2, type + " " + JU.PT.escF (as.mads[i] / 2000));
-}}if (as.bsColixSet != null && as.bsColixSet.get (i)) JU.BSUtil.setMapBitSet (temp2, atomIndex1, atomIndex2, J.shape.Shape.getColorCommand (type, as.paletteIDs[i], as.colixes[i], shape.translucentAllowed));
-}
-}, "J.shape.AtomShape,J.shape.Shape,~N,~A,JU.BS,java.util.Map,java.util.Map");
 Clazz.overrideMethod (c$, "getMeasurementState", 
 function (shape, mList, measurementCount, font3d, ti) {
 var commands =  new JU.SB ();
@@ -656,19 +648,6 @@ Clazz.defineMethod (c$, "clearTemp",
 this.temp.clear ();
 this.temp2.clear ();
 });
-Clazz.overrideMethod (c$, "getAtomShapeSetState", 
-function (shape, bioShapes) {
-this.clearTemp ();
-for (var i = bioShapes.length; --i >= 0; ) {
-var bs = bioShapes[i];
-if (bs.monomerCount > 0) {
-if (!bs.isActive || bs.bsSizeSet == null && bs.bsColixSet == null) continue;
-this.vwr.getShapeSetState (bs, shape, bs.monomerCount, bs.getMonomers (), bs.bsSizeDefault, this.temp, this.temp2);
-}}
-var s = "\n" + this.getCommands (this.temp, this.temp2, shape.shapeID == 9 ? "Backbone" : "select");
-this.clearTemp ();
-return s;
-}, "J.shape.Shape,~A");
 Clazz.defineMethod (c$, "getShapeState", 
 function (shape) {
 var s;
