@@ -5,6 +5,11 @@
 
 // see JSmolApi.js for public user-interface. All these are private functions
 
+// BH 1/15/2016 4:23:14 PM adding Info.makeLiveImage
+// BH 12/30/2015 8:18:42 PM adding AMS call to database list; allowing for ?ALLOWSORIGIN? to override settings here
+// BH 12/17/2015 4:43:05 PM adding Jmol._requestRepaint to allow for MSIE9 not having requestAnimationFrame
+// BH 12/16/2015 3:01:06 PM adding $.ajaxSetup({ mimeType: "text/plain" });
+// BH 12/14/2015 6:42:03 PM adding check for MS Edge browser, which does not support dataURI
 // BH 12/2/2015 1:18:15 PM adding .dcd as binary file type
 // BH 12/1/2015 10:05:55 AM loading identical HTML5 page after Java page causes bad NPObject error 
 // BH 10/26/2015 12:47:16 PM adding two rcsb sites for direct access
@@ -144,7 +149,7 @@ Jmol = (function(document) {
 		}
 	};
 	var j = {
-		_version: "$Date: 2015-12-05 05:28:12 -0600 (Sat, 05 Dec 2015) $", // svn.keywords:lastUpdated
+		_version: "$Date: 2016-01-15 17:26:30 -0500 (Fri, 15 Jan 2016) $", // svn.keywords:lastUpdated
 		_alertNoBinary: true,
 		// this url is used to Google Analytics tracking of Jmol use. You may remove it or modify it if you wish. 
 		_allowedJmolSize: [25, 2048, 300],   // min, max, default (pixels)
@@ -172,16 +177,18 @@ Jmol = (function(document) {
 			_nciLoadScript: ";n = ({molecule=1}.length < {molecule=2}.length ? 2 : 1); select molecule=n;display selected;center selected;",
 			_pubChemLoadScript: "",
 			_DirectDatabaseCalls:{
-				// these sites are known to implement access-control-allow-origin * 
-				"cactus.nci.nih.gov": "%URL", 
-				"www.rcsb.org": "%URL",
-				"cdn.rcsb.org": "%URL",
-				"ftp.wwpdb.org": "%URL",
-				"pdbe.org": "%URL", 
-				"www.ebi.ac.uk": "%URL", 
-				"wwwdev.ebi.ac.uk": "%URL", 
-				"pubchem.ncbi.nlm.nih.gov":"%URL",
-				"http://www.nmrdb.org/tools/jmol/predict.php":"%URL",
+				// these sites are known to implement access-control-allow-origin *
+        // null here means no conversion necessary 
+				"cactus.nci.nih.gov": null,
+        "rruff.geo.arizona.edu": null, 
+				"www.rcsb.org": null,
+				"cdn.rcsb.org": null,
+				"ftp.wwpdb.org": null,
+				"pdbe.org": null, 
+				"www.ebi.ac.uk": null, 
+				"wwwdev.ebi.ac.uk": null, 
+				"pubchem.ncbi.nlm.nih.gov":null,
+				"http://www.nmrdb.org/tools/jmol/predict.php":null,
 				"$": "http://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf&get3d=True",
 				"$$": "http://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf",
 				"=": "http://www.rcsb.org/pdb/files/%FILE.pdb",
@@ -209,6 +216,8 @@ Jmol = (function(document) {
 	var ref = document.location.href.toLowerCase();
 	j._httpProto = (ref.indexOf("https") == 0 ? "https://" : "http://"); 
 	j._isFile = (ref.indexOf("file:") == 0);
+	if (j._isFile) // ensure no attempt to read XML in local request:
+	  $.ajaxSetup({ mimeType: "text/plain" });
 	j._ajaxTestSite = j._httpProto + "google.com";
 	var isLocal = (j._isFile || ref.indexOf("http://localhost") == 0 || ref.indexOf("http://127.") == 0);
 	j._tracker = (j._httpProto == "http://" && !isLocal && 'http://chemapps.stolaf.edu/jmol/JmolTracker.htm?id=UA-45940799-1');
@@ -216,8 +225,10 @@ Jmol = (function(document) {
 	j._isChrome = (navigator.userAgent.toLowerCase().indexOf("chrome") >= 0);
 	j._isSafari = (!j._isChrome && navigator.userAgent.toLowerCase().indexOf("safari") >= 0);
 	j._isMsie = (window.ActiveXObject !== undefined);
-	j._useDataURI = !j._isSafari && !j._isMsie; // safari may be OK here -- untested
+  j._isEdge = (navigator.userAgent.indexOf("Edge/") >= 0);
+	j._useDataURI = !j._isSafari && !j._isMsie && !j._isEdge; // safari may be OK here -- untested
 
+  window.requestAnimationFrame || (window.requestAnimationFrame = window.setTimeout);
 	for(var i in Jmol) j[i] = Jmol[i]; // allows pre-definition
 	return j;
 })(document, Jmol);
@@ -614,16 +625,16 @@ Jmol = (function(document) {
 		return (Jmol.db._databasePrefixes.indexOf(query.substring(0, 1)) >= 0);
 	}
 
-	
 	Jmol._getDirectDatabaseCall = function(query, checkXhr2) {
 		if (checkXhr2 && !Jmol.featureDetection.supportsXhr2())
 			return query;
 		var pt = 2;
-		var db;
-		var call = Jmol.db._DirectDatabaseCalls[query.substring(0,pt)]
-      || Jmol.db._DirectDatabaseCalls[db = query.substring(0,--pt)];
+		var db = query.substring(0,pt)
+		var call = Jmol.db._DirectDatabaseCalls[db] || Jmol.db._DirectDatabaseCalls[db = query.substring(0,--pt)];
 		if (call) {
+      // one of the special set :, =, $, ==
 			if (db == ":") {
+        // PubChem
 				var ql = query.toLowerCase();
 				if (!isNaN(parseInt(query.substring(1)))) {
 					query = "cid/" + query.substring(1);
@@ -648,7 +659,7 @@ Jmol = (function(document) {
 			} else {
 				query = call.replace(/\%FILE/, query);
 			}
-		}		
+		}
 		return query;
 	}
 
@@ -715,7 +726,6 @@ Jmol = (function(document) {
 	Jmol._getInfoFromDatabase = function(applet, database, query){
 		if (database == "====") {
 			var data = Jmol.db._restQueryXml.replace(/QUERY/,query);
-
 			var info = {
 				dataType: "text",
 				type: "POST",
@@ -895,6 +905,10 @@ Jmol = (function(document) {
 		var isMyHost = (fileName.indexOf("://") < 0 || fileName.indexOf(document.location.protocol) == 0 && fileName.indexOf(document.location.host) >= 0);
     var isHttps2Http = (Jmol._httpProto == "https://" && fileName.indexOf("http://") == 0);
 		var isDirectCall = Jmol._isDirectCall(fileName);
+    if (!isDirectCall && fileName.indexOf("?ALLOWSORIGIN?") >= 0) {
+      isDirectCall = true;
+			fileName = fileName.replace(/\?ALLOWSORIGIN\?/,"");
+    }
 		//if (fileName.indexOf("http://pubchem.ncbi.nlm.nih.gov/") == 0)isDirectCall = false;
 
 		var cantDoSynchronousLoad = (!isMyHost && Jmol.$supportsIECrossDomainScripting());
@@ -940,6 +954,8 @@ Jmol = (function(document) {
 	}
 
 	Jmol._isDirectCall = function(url) {
+    if (url.indexOf("?ALLOWSORIGIN?") >= 0)
+      return true;
 		for (var key in Jmol.db._DirectDatabaseCalls) {
 			if (key.indexOf(".") >= 0 && url.indexOf(key) >= 0)
 				return true;
@@ -1022,17 +1038,6 @@ Jmol = (function(document) {
 		fileLoadThread.setData(filename, filename0, data, appData);
   }
   
-	Jmol._toBytes = function(data) {
-	if (typeof data == "string") 
-		return data.getBytes();
-	// ArrayBuffer assumed here
-	data = new Uint8Array(data);
-	var b = Clazz.newByteArray(data.length, 0);
-		for (var i = data.length; --i >= 0;)
-			b[i] = data[i];
-	return b;
-	}
-
 	Jmol._doAjax = function(url, postOut, dataOut) {
 		// called by org.jmol.awtjs2d.JmolURLConnection.doAjax()
 		url = url.toString();
@@ -1100,7 +1105,7 @@ Jmol = (function(document) {
 
 	Jmol._strToBytes = function(s) {
 		if (Clazz.instanceOf(s, self.ArrayBuffer))
-			return Jmol._toBytes(s);
+			return Clazz.newByteArray(-1, s);
 		var b = Clazz.newByteArray(s.length, 0);
 		for (var i = s.length; --i >= 0;)
 			b[i] = s.charCodeAt(i) & 0xFF;
@@ -1115,7 +1120,7 @@ Jmol = (function(document) {
 	}
 
 	Jmol._registerApplet = function(id, applet) {
-		return window[id] = Jmol._applets[id] = Jmol._applets[applet] = Jmol._applets[id + "__" + Jmol._syncId + "__"] = applet;
+		return window[id] = Jmol._applets[id] = Jmol._applets[id + "__" + Jmol._syncId + "__"] = applet;
 	} 
 
 	Jmol._readyCallback = function (appId,fullId,isReady,javaApplet,javaAppletPanel) {
@@ -1158,7 +1163,7 @@ Jmol = (function(document) {
 			var img = ""; 
 			if (applet._coverImage){
 				var more = " onclick=\"Jmol.coverApplet(ID, false)\" title=\"" + (applet._coverTitle) + "\"";
-				var play = "<image id=\"ID_coverclickgo\" src=\"" + applet._j2sPath + "/img/play_make_live.jpg\" style=\"width:25px;height:25px;position:absolute;bottom:10px;left:10px;"
+				var play = "<image id=\"ID_coverclickgo\" src=\"" + applet._makeLiveImg + "\" style=\"width:25px;height:25px;position:absolute;bottom:10px;left:10px;"
 					+ "z-index:" + Jmol._getZ(applet, "coverImage")+";opacity:0.5;\"" + more + " />"  
 				img = "<div id=\"ID_coverdiv\" style=\"background-color:red;z-index:" + Jmol._getZ(applet, "coverImage")+";width:100%;height:100%;display:inline;position:absolute;top:0px;left:0px\"><image id=\"ID_coverimage\" src=\""
 				 + applet._coverImage + "\" style=\"width:100%;height:100%\"" + more + "/>" + play + "</div>";
@@ -1316,6 +1321,7 @@ Jmol = (function(document) {
 		Jmol._j2sPath && (Info.j2sPath = Jmol._j2sPath);
 		obj._j2sPath = Info.j2sPath;
 		obj._coverImage = Info.coverImage;
+    obj._makeLiveImage = Info.makeLiveImage || Info._j2sPath + "/img/play_make_live.jpg";
 		obj._isCovered = !!obj._coverImage; 
 		obj._deferApplet = Info.deferApplet || obj._isCovered && obj._isJava; // must do this if covered in Java
 		obj._deferUncover = Info.deferUncover && !obj._isJava; // can't do this with Java
@@ -1977,12 +1983,14 @@ Jmol._track = function(applet) {
 	return applet;
 }
 
-Jmol.getProfile = function() {
-	window["j2s.doProfile"] = true;
-	if (self.Clazz && self.JSON) {
-		Clazz._profile || (Clazz._profile = {});
-		return Clazz.getProfile();
-	}
+var __profiling;
+
+Jmol.getProfile = function(doProfile) {
+  if (!self.Clazz || !self.JSON)
+    return;
+  if (!__profiling)
+    Clazz._startProfiling(__profiling = (arguments.length == 0 || doProfile));
+	return Clazz.getProfile();
 }
 
 Jmol._getInChIKey = function(applet, data) {
@@ -2226,7 +2234,7 @@ Jmol.Cache.put = function(filename, data) {
 			reader.onloadend = function(evt) {
 				if (evt.target.readyState == FileReader.DONE) {
 					var cacheName = "cache://DROP_" + file.name;
-					var bytes = Jmol._toBytes(evt.target.result);
+					var bytes = Clazz.newByteArray(-1, evt.target.result);
 					if (!cacheName.endsWith(".spt"))
 						me._appletPanel.cacheFileByName("cache://DROP_*",false);
 					if (me._viewType == "JSV" || cacheName.endsWith(".jdx")) // shared by Jmol and JSV
